@@ -29,6 +29,7 @@ from capella_console_client.assets import (
     _filter_items_by_product_types,
 )
 from capella_console_client.search import StacSearch, SearchResult
+from capella_console_client.tasking import get_tasking_requests, _task_contains_status
 from capella_console_client.validate import (
     _validate_uuid,
     _validate_stac_id_or_stac_items,
@@ -100,50 +101,27 @@ class CapellaConsoleClient:
 
     # TASKING
     def list_tasking_requests(
-        self,
-        *tasking_request_ids: Optional[str],
-        for_org: Optional[bool] = False,
-        status: Optional[str] = None,
+        self, *tasking_request_ids: Optional[str], for_org: Optional[bool] = False, **kwargs: Optional[Dict[str, Any]]
     ) -> List[Dict[str, Any]]:
         """
-        list tasking requests
+        list/ search tasking requests
+
+        Find more information at https://docs.capellaspace.com/constellation-tasking/tasking-requests
 
         Args:
             tasking_request_ids: list only specific tasking_request_ids (variadic, specify multiple)
             for_org: list all tasking requests of your organization (instead of only yours) - **requires** organization index/ admin permission
-            status: list only tasking requests that are in this/ have passed this status, e.g. completed
+
+        additionally the following search filters are supported:
+
+         • status: TaskingRequestStatus, one of received, review, submitted, active, accepted, rejected, expired, completed, anomaly, canceled, error, failed
+         • submission_time__gt: datetime, e.g. datetime.datetime(2022, 12, 9, 21)
+
 
         Returns:
             List[Dict[str, Any]]: metadata of tasking requests
         """
-        tasking_request_meta = []
-
-        if tasking_request_ids:
-            for t_req_id in tasking_request_ids:
-                _validate_uuid(t_req_id)
-
-        # get selected
-        if tasking_request_ids:
-            tasking_request_meta = [self.get_task(t_req_id) for t_req_id in tasking_request_ids]  # type: ignore
-            if status:
-                tasking_request_meta = [
-                    t_meta for t_meta in tasking_request_meta if self._task_contains_status(t_meta, status)
-                ]
-            return tasking_request_meta
-
-        if for_org:
-            params = {"organizationId": self._sesh.organization_id}
-        else:
-            params = {"customerId": self._sesh.customer_id}
-
-        resp = self._sesh.get("/tasks", params=params)
-        tasking_request_meta = resp.json()
-
-        if status:
-            tasking_request_meta = [
-                t_meta for t_meta in tasking_request_meta if self._task_contains_status(t_meta, status)
-            ]
-        return tasking_request_meta
+        return get_tasking_requests(*tasking_request_ids, session=self._sesh, for_org=for_org, **kwargs)
 
     def get_task(self, tasking_request_id: str) -> Dict[str, Any]:
         """
@@ -158,14 +136,11 @@ class CapellaConsoleClient:
         task_response = self._sesh.get(f"/task/{tasking_request_id}")
         return task_response.json()
 
-    def _task_contains_status(self, task: Dict[str, Any], status_name: str) -> bool:
-        return status_name.lower() in (s["code"] for s in task["properties"]["statusHistory"])
-
     def is_task_completed(self, task: Dict[str, Any]) -> bool:
         """
         check if a task has completed
         """
-        return self._task_contains_status(task, "completed")
+        return _task_contains_status(task, "completed")
 
     def get_collects_for_task(self, tasking_request_id: str) -> List[Dict[str, Any]]:
         """
